==> jc-1.4.0.tar.gz: javax/print/PrintServiceLookup.h <==
// public abstract class javax.print.PrintServiceLookup

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5ccdc07b77703271 javax_print_PrintServiceLookup

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_print_PrintServiceLookup_H_
#define _JC_javax_print_PrintServiceLookup_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_print_DocFlavor$object;
struct _jc_javax_print_PrintService$object;
struct _jc_javax_print_attribute_AttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_PrintServiceLookup$sub_refs	_jc_javax_print_PrintServiceLookup$sub_refs;
typedef struct _jc_javax_print_PrintServiceLookup$sub_nonrefs	_jc_javax_print_PrintServiceLookup$sub_nonrefs;
typedef struct _jc_javax_print_PrintServiceLookup$refs	_jc_javax_print_PrintServiceLookup$refs;
typedef struct _jc_javax_print_PrintServiceLookup$nonrefs	_jc_javax_print_PrintServiceLookup$nonrefs;
typedef struct _jc_javax_print_PrintServiceLookup$object	_jc_javax_print_PrintServiceLookup$object;

typedef const struct _jc_javax_print_PrintServiceLookup$vmethods	_jc_javax_print_PrintServiceLookup$vmethods;
typedef const struct _jc_javax_print_PrintServiceLookup$vtable	_jc_javax_print_PrintServiceLookup$vtable;
typedef const struct _jc_javax_print_PrintServiceLookup$vtype	_jc_javax_print_PrintServiceLookup$vtype;

// Constructors
extern void _jc_javax_print_PrintServiceLookup$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_print_PrintServiceLookup$object *);

// Virtual methods
extern struct _jc_object *_jc_javax_print_PrintServiceLookup$method$getDefaultPrintService$348d339c6d9a1f36(_jc_env *, struct _jc_javax_print_PrintServiceLookup$object *);
extern _jc_object_array *_jc_javax_print_PrintServiceLookup$method$getMultiDocPrintServices$481c2bee3dc84360(_jc_env *, struct _jc_javax_print_PrintServiceLookup$object *, struct _jc_object_array *, struct _jc_object *);
extern _jc_object_array *_jc_javax_print_PrintServiceLookup$method$getPrintServices$f1b8c817ca020ee3(_jc_env *, struct _jc_javax_print_PrintServiceLookup$object *);
extern _jc_object_array *_jc_javax_print_PrintServiceLookup$method$getPrintServices$68f2e8d7eba25743(_jc_env *, struct _jc_javax_print_PrintServiceLookup$object *, struct _jc_javax_print_DocFlavor$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_PrintServiceLookup$method_info$getDefaultPrintService$348d339c6d9a1f36;
extern _jc_method _jc_javax_print_PrintServiceLookup$method_info$getMultiDocPrintServices$481c2bee3dc84360;
extern _jc_method _jc_javax_print_PrintServiceLookup$method_info$getPrintServices$f1b8c817ca020ee3;
extern _jc_method _jc_javax_print_PrintServiceLookup$method_info$getPrintServices$68f2e8d7eba25743;

// Virtual methods structure
struct _jc_javax_print_PrintServiceLookup$vmethods {
	struct _jc_object	*(*getDefaultPrintService$348d339c6d9a1f36)(_jc_env *, struct _jc_javax_print_PrintServiceLookup$object *);
	_jc_object_array	*(*getMultiDocPrintServices$481c2bee3dc84360)(_jc_env *, struct _jc_javax_print_PrintServiceLookup$object *, struct _jc_object_array *, struct _jc_object *);
	_jc_object_array	*(*getPrintServices$f1b8c817ca020ee3)(_jc_env *, struct _jc_javax_print_PrintServiceLookup$object *);
	_jc_object_array	*(*getPrintServices$68f2e8d7eba25743)(_jc_env *, struct _jc_javax_print_PrintServiceLookup$object *, struct _jc_javax_print_DocFlavor$object *, struct _jc_object *);
};

// Vtable
struct _jc_javax_print_PrintServiceLookup$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_PrintServiceLookup$vmethods	javax_print_PrintServiceLookup;
};

// Vtype
struct _jc_javax_print_PrintServiceLookup$vtype {
	_jc_type			type;
	_jc_javax_print_PrintServiceLookup$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_PrintServiceLookup$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_PrintServiceLookup$refs {
    _jc_javax_print_PrintServiceLookup$sub_refs	javax_print_PrintServiceLookup;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_PrintServiceLookup$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_PrintServiceLookup$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_PrintServiceLookup$sub_nonrefs	javax_print_PrintServiceLookup;
};

// Object instance structure
struct _jc_javax_print_PrintServiceLookup$object {
	_jc_javax_print_PrintServiceLookup$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_PrintServiceLookup$vtype	*vtype;
	_jc_javax_print_PrintServiceLookup$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_PrintServiceLookup$vtype _jc_javax_print_PrintServiceLookup$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_PrintServiceLookup, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_PrintServiceLookup$class_object;

#endif	/* _JC_javax_print_PrintServiceLookup_H_ */

==> jc-1.4.6.tar.gz: javax/print/PrintServiceLookup.h <==
// public abstract class javax.print.PrintServiceLookup

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5ccdc07b77703271 javax_print_PrintServiceLookup

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_print_PrintServiceLookup_H_
#define _JC_javax_print_PrintServiceLookup_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_print_DocFlavor$object;
struct _jc_javax_print_PrintService$object;
struct _jc_javax_print_attribute_AttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_PrintServiceLookup$sub_refs	_jc_javax_print_PrintServiceLookup$sub_refs;
typedef struct _jc_javax_print_PrintServiceLookup$sub_nonrefs	_jc_javax_print_PrintServiceLookup$sub_nonrefs;
typedef struct _jc_javax_print_PrintServiceLookup$refs	_jc_javax_print_PrintServiceLookup$refs;
typedef struct _jc_javax_print_PrintServiceLookup$nonrefs	_jc_javax_print_PrintServiceLookup$nonrefs;
typedef struct _jc_javax_print_PrintServiceLookup$object	_jc_javax_print_PrintServiceLookup$object;

typedef const struct _jc_javax_print_PrintServiceLookup$vmethods	_jc_javax_print_PrintServiceLookup$vmethods;
typedef const struct _jc_javax_print_PrintServiceLookup$vtable	_jc_javax_print_PrintServiceLookup$vtable;
typedef const struct _jc_javax_print_PrintServiceLookup$vtype	_jc_javax_print_PrintServiceLookup$vtype;

// Constructors
extern void _jc_javax_print_PrintServiceLookup$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_print_PrintServiceLookup$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_print_PrintServiceLookup$method$getDefaultPrintService$348d339c6d9a1f36(_jc_env *, struct _jc_javax_print_PrintServiceLookup$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_javax_print_PrintServiceLookup$method$getMultiDocPrintServices$481c2bee3dc84360(_jc_env *, struct _jc_javax_print_PrintServiceLookup$object *, struct _jc_object_array *, struct _jc_object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_javax_print_PrintServiceLookup$method$getPrintServices$f1b8c817ca020ee3(_jc_env *, struct _jc_javax_print_PrintServiceLookup$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_javax_print_PrintServiceLookup$method$getPrintServices$68f2e8d7eba25743(_jc_env *, struct _jc_javax_print_PrintServiceLookup$object *, struct _jc_javax_print_DocFlavor$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_PrintServiceLookup$method_info$getDefaultPrintService$348d339c6d9a1f36;
extern _jc_method _jc_javax_print_PrintServiceLookup$method_info$getMultiDocPrintServices$481c2bee3dc84360;
extern _jc_method _jc_javax_print_PrintServiceLookup$method_info$getPrintServices$f1b8c817ca020ee3;
extern _jc_method _jc_javax_print_PrintServiceLookup$method_info$getPrintServices$68f2e8d7eba25743;

// Virtual methods structure
struct _jc_javax_print_PrintServiceLookup$vmethods {
	struct _jc_object	*(*getDefaultPrintService$348d339c6d9a1f36)(_jc_env *, struct _jc_javax_print_PrintServiceLookup$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getMultiDocPrintServices$481c2bee3dc84360)(_jc_env *, struct _jc_javax_print_PrintServiceLookup$object *, struct _jc_object_array *, struct _jc_object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getPrintServices$f1b8c817ca020ee3)(_jc_env *, struct _jc_javax_print_PrintServiceLookup$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getPrintServices$68f2e8d7eba25743)(_jc_env *, struct _jc_javax_print_PrintServiceLookup$object *, struct _jc_javax_print_DocFlavor$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_PrintServiceLookup$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_PrintServiceLookup$vmethods	javax_print_PrintServiceLookup;
};

// Vtype
struct _jc_javax_print_PrintServiceLookup$vtype {
	_jc_type			type;
	_jc_javax_print_PrintServiceLookup$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_PrintServiceLookup$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_PrintServiceLookup$refs {
    _jc_javax_print_PrintServiceLookup$sub_refs	javax_print_PrintServiceLookup;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_PrintServiceLookup$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_PrintServiceLookup$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_PrintServiceLookup$sub_nonrefs	javax_print_PrintServiceLookup;
};

// Object instance structure
struct _jc_javax_print_PrintServiceLookup$object {
	_jc_javax_print_PrintServiceLookup$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_PrintServiceLookup$vtype	*vtype;
	_jc_javax_print_PrintServiceLookup$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_PrintServiceLookup$vtype _jc_javax_print_PrintServiceLookup$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_PrintServiceLookup, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_PrintServiceLookup$class_object;

#endif	/* _JC_javax_print_PrintServiceLookup_H_ */
